import request from '@/utils/request'

// 查询学习分类列表
export function examElCategoryTreeList(query,type) {
  return request({
    url: '/exam/elCategory/treeList/0/'+type,
    method: 'get',
    params: query
  })
}
// 查询学习分类详细
export function getEl_category(id) {
  return request({
    url: '/exam/el_category/' + id,
    method: 'get'
  })
}
// 删除学习分类
export function examElCategoryDel(data) {
  return request({
    url: '/exam/elCategory/del',
    method: 'post',
    data: data
  })
}
// 新增学习分类
export function examElCategoryAdd(data) {
  return request({
    url: '/exam/elCategory/add',
    method: 'post',
    data: data
  })
}
// 修改学习分类
export function examElCategoryEdit(data) {
  return request({
    url: '/exam/elCategory/edit',
    method: 'post',
    data: data
  })
}

//课后考科提交
export function examElChapterAssessFinish(id) {
  return request({
    url: '/exam/elChapter/assessFinish/'+id,
    method: 'post',
  })
}

//考核记录列表
export function examElChapterAssessDetail(data) {
  return request({
    url: '/exam/elChapter/assessDetail',
    method: 'post',
    data:data
  })
}

//考核记录列表
export function examElChapterAssessList(data) {
  return request({
    url: '/exam/elChapter/assessList',
    method: 'post',
    data:data
  })
}
//考核记录列表-查询某个章节下-某个用户的考核记录
export function examElChapterAssessListByUserId(data) {
  return request({
    url: '/exam/elChapter/assessListByUserId',
    method: 'post',
    data:data
  })
}

//获取章节题目信息
export function examElChapterQueryChapterQu(data) {
  return request({
    url: '/exam/elChapter/queryChapterQu',
    method: 'post',
    data:data,
  })
}

//根据人员课程学习状况
export function examElCourseInfo(query) {
  return request({
    url: '/exam/elCourse/'+query.userId+'/'+query.id,
    method: 'get',
  })
}


// 查询学习资源详细
export function examElCourse(id) {
  return request({
    url: '/exam/elCourse/' + id,
    method: 'get'
  })
}

//根据课程查询学习人员列表
export function examElCourseLearnList(data) {
  return request({
    url: '/exam/elCourse/learn/list',
    method: 'post',
    data: data
  })
}
//根据课程查询学习人员列表
export function examElCourseLearningRecordsList(data) {
  return request({
    url: '/exam/elCourse/learningRecordsList',
    method: 'post',
    data: data
  })
}

// 查询问题题目列表
export function examQuList(data) {
  return request({
    url: '/exam/qu/list',
    method: 'post',
    data: data
  })
}

// 题目类型列表
export function examElClassifyQueryOption(data) {
  return request({
    url: '/exam/elClassify/queryOption',
    method: 'post',
    data: data
  })
}

// 查询课件资源列表
export function examElResourcesList(data) {
  return request({
    url: '/exam/elResources/list',
    method: 'post',
    data: data
  })
}
// 新增学习资源
export function examElCourseAdd(data) {
  return request({
    url: '/exam/elCourse/add',
    method: 'post',
    data: data
  })
}
// 修改学习资源
export function examElCourseEdit(data) {
  return request({
    url: '/exam/elCourse/edit',
    method: 'post',
    data: data
  })
}
// 新增章节
export function examElChapterAdd(data) {
  return request({
    url: '/exam/elChapter/add',
    method: 'post',
    data: data
  })
}
// 修改章节
export function examElChapterEdit(data) {
  return request({
    url:  '/exam/elChapter/edit',
    method: 'post',
    data: data
  })
}
// 删除章节
export function examElChapterDel(data) {
  return request({
    url: '/exam/elChapter/del ',
    method: 'post',
    data:data
  })
}
// 查询学习资源列表
export function examElCourseCourseList(query) {
  return request({
    url: '/exam/elCourse/course/list',
    method: 'get',
    params: query
  })
}

// 删除学习资源
export function examElCourseDel(data) {
  return request({
    url: '/exam/elCourse/del',
    method: 'post',
    data:data
  })
}

// 删除课件资源
export function examElResourcesDel(id) {
  return request({
    url: '/exam/elResources/del/' + id,
    method: 'get'
  })
}

// 新增课件资源
export function examElResourcesAdd(data) {
  return request({
    url: '/exam/elResources/add',
    method: 'post',
    data: data
  })
}
// 修改课件资源
export function examElResourcesUpdate(data) {
  return request({
    url: '/exam/elResources/update',
    method: 'post',
    data: data
  })
}
// 新增富文本课件资源
export function examElResourcesAddText(data) {
  return request({
    url: '/exam/elResources/addText',
    method: 'post',
    data: data
  })
}
// 修改富文本
export function examElResourcesUpdateText(data) {
  return request({
    url: '/exam/elResources/updateText',
    method: 'post',
    data: data
  })
}

// 查询危化品安全技术说明书列表
export function listHazard_book(query) {
  return request({
    url: '/laboratory/hazard_book/list',
    method: 'get',
    params: query
  })
}
// 查询危化品安全技术说明书详细
export function getHazard_book(id) {
  return request({
    url: '/laboratory/hazard_book/' + id,
    method: 'get'
  })
}
// 删除危化品安全技术说明书
export function delHazard_book(id) {
  return request({
    url: '/laboratory/hazard_book/' + id,
    method: 'delete'
  })
}
// 新增危化品安全技术说明书
export function addHazard_book(data) {
  return request({
    url: '/laboratory/hazard_book',
    method: 'post',
    data: data
  })
}
// 修改危化品安全技术说明书
export function updateHazard_book(data) {
  return request({
    url: '/laboratory/hazard_book',
    method: 'put',
    data: data
  })
}
// 查询实验室安全制度列表
export function laboratorySafeBookList(data) {
  return request({
    url: '/laboratory/safeBook/list',
    method: 'post',
    data: data
  })
}

// 查询实验室安全制度详细
export function laboratorySafeBook(id) {
  return request({
    url: '/laboratory/safeBook/' + id,
    method: 'get'
  })
}
// 删除实验室安全制度
export function laboratorySafeBookDel(data) {
  return request({
    url:'/laboratory/safeBook/del',
    method: 'post',
    data:data
  })
}
// 新增实验室安全制度
export function laboratorySafeBookAdd(data) {
  return request({
    url: '/laboratory/safeBook/add',
    method: 'post',
    data: data
  })
}
// 修改实验室安全制度
export function laboratorySafeBookEdit(data) {
  return request({
    url: '/laboratory/safeBook/edit',
    method: 'post',
    data: data
  })
}

// 查询问题和选项
export function paperDetail(data) {
  return request({
    url: '/exam/paper/paperDetail',
    method: 'post',
    data: data
  })
}

//获取问题
export function examElPractisePaperDetail(data) {
  return request({
    url: '/exam/elPractise/paperDetail',
    method: 'post',
    data: data
  })
}
// 保存用户答案
export function fillAnswer(data) {
  return request({
    url: '/exam/paper/fillAnswer',
    method: 'post',
    data: data
  })
}
//问题提交
export function examElPractiseFillAnswer(data) {
  return request({
    url: '/exam/elPractise/fillAnswer',
    method: 'post',
    data: data
  })
}
// 交卷
export function handPaper(data) {
  return request({
    url: '/exam/paper/handPaper',
    method: 'post',
    data: data
  })
}
//交卷
export function examElPractiseHandPractise(data) {
  return request({
    url: '/exam/elPractise/handPractise',
    method: 'post',
    data: data
  })
}
//查询考试结果
export function paperResult(data) {
  return request({
    url: '/exam/paper/paperResult',
    method: 'post',
    data: data
  })
}

//开始学习
export function examElCourseLearnStart(data) {
  return request({
    url: '/exam/elCourse/learn/start',
    method: 'post',
    data: data
  })
}
// 完成学习
export function examElCourseLearnFinish(data) {
  return request({
    url: '/exam/elCourse/learn/finish',
    method: 'post',
    data: data
  })
}

// 查询学习资源/记录-详情
export function examElCourseLearn(id) {
  return request({
    url: '/exam/elCourse/learn/'+id,
    method: 'get',
  })
}

//开始课后考核
export function examElChapterAssessStart(data) {
  return request({
    url: '/exam/elChapter/assessStart',
    method: 'post',
    data:data
  })
}

// 查询证书管理列表
export function examCertificateList(data) {
  return request({
    url: '/exam/certificate/list',
    method: 'post',
    data: data
  })
}
// 查询证书管理详细
export function examCertificateInfo(id) {
  return request({
    url: '/exam/certificate/' + id,
    method: 'get'
  })
}
// 删除证书管理
export function examCertificateDel(data) {
  return request({
    url: '/exam/certificate/del',
    method: 'post',
    data:data
  })
}
// 新增证书管理
export function examCertificateAdd(data) {
  return request({
    url: '/exam/certificate/add',
    method: 'post',
    data: data
  })
}
// 修改证书管理
export function examCertificateEdit(data) {
  return request({
    url: '/exam/certificate/edit',
    method: 'post',
    data: data
  })
}

// 查询题目类型列表
export function examElClassifyList(data) {
  return request({
    url: '/exam/elClassify/list',
    method: 'post',
    data: data
  })
}
// 查询题目类型详细
export function examElClassify(id) {
  return request({
    url: '/exam/elClassify/'+id,
    method: 'get',
  })
}
// 删除题目类型
export function examElClassifyDel(data) {
  return request({
    url: '/exam/elClassify/del',
    method: 'post',
    data:data
  })
}
// 新增题目类型
export function examElClassifyAdd(data) {
  return request({
    url: '/exam/elClassify/add',
    method: 'post',
    data: data
  })
}
// 修改题目类型
export function examElClassifyEdit(data) {
  return request({
    url: '/exam/elClassify/edit',
    method: 'post',
    data: data
  })
}

// 查询题库下拉列表
export function examRepoQueryOption(data) {
  return request({
    url: '/exam/repo/queryOption',
    method: 'post',
    data: data
  })
}
// 新增考试
export function examExamAdd(data) {
  return request({
    url: '/exam/exam/add',
    method: 'post',
    data: data
  })
}
//考试管理详情列表
export function examUserExamList(data) {
  return request({
    url: '/exam/user/exam/list',
    method: 'post',
    data: data
  })
}
// 根据主键查询考试明细
export function examExamInfo(id) {
  return request({
    url: '/exam/exam/' + id,
    method: 'get'
  })
}
// 修改考试
export function examExamEdit(data) {
  return request({
    url: '/exam/exam/edit',
    method: 'post',
    data: data
  })
}

// 查询试卷管理列表
export function listPaper(data) {
  return request({
    url: '/exam/paper/list',
    method: 'post',
    data: data
  })
}

// 修改考试
export function updateExam(data) {
  return request({
    url: '/exam/exam',
    method: 'put',
    data: data
  })
}


// 查询考试记录详细
export function userGetExam(id) {
  return request({
    url: '/exam/user/exam/' + id,
    method: 'get'
  })
}

// 查询考试详细
export function getExam(id) {
  return request({
    url: '/exam/exam/' + id,
    method: 'get'
  })
}

// 删除考试
export function examExamDel(data) {
  return request({
    url: '/exam/exam/del',
    method: 'post',
    data:data

  })
}

// 查询学习资源下拉列表
export function examElCourseQueryOption(data) {
  return request({
    url: '/exam/elCourse/queryOption',
    method: 'post',
    data: data
  })
}

// 查询证书下拉框
export function certificateOption(data) {
  return request({
    url: '/exam/certificate/queryOption',
    method: 'post',
    data: data
  })
}

// 查询考试列表
export function examExamList(data) {
  return request({
    url: '/exam/exam/list',
    method: 'post',
    data: data
  })
}

// 修改考试关联的培训
export function updateSafeTrain(data) {
  return request({
    url: '/exam/exam/saveSafeTrainById',
    method: 'post',
    data: data
  })
}

// 修改考试关联的证书
export function updateCert(data) {
  return request({
    url: '/exam/exam/saveCertById',
    method: 'post',
    data: data
  })
}

// 查询个人考试列表
export function examExamOnlineExamList(data) {
  return request({
    url: '/exam/exam/onlineExamList',
    method: 'post',
    data: data
  })
}

// 查询考试记录列表
export function myListExam(query) {
  return request({
    url: '/exam/user/exam/list/my',
    method: 'get',
    params: query
  })
}
// 组卷
export function examPaperCreatePaper(data) {
  return request({
    url: '/exam/paper/createPaper',
    method: 'post',
    data: data
  })
}
// 开始考试
export function paperId(id) {
  return request({
    url: '/exam/paper/'+id,
    method: 'get',
  })
}

// 查询试卷管理列表
export function examPaperListAll(data) {
  return request({
    url: '/exam/paper/listAll',
    method: 'post',
    data: data
  })
}
// 查询考试结果
export function getExamPaper(id) {
  return request({
    url: '/exam/paper/'+id,
    method: 'get',
  })
}
//个人证书
export function examExamQueryMyCert(data) {
  return request({
    url: '/exam/exam/queryMyCert',
    method: 'post',
    data: data
  })
}

//点击开始练习
export function examElPractiseStart(data) {
  return request({
    url: '/exam/elPractise/start',
    method: 'post',
    data:data
  })
}
// 查询模拟练习类型
export function getQueryOption(data) {
  return request({
    url: '/exam/el_classify/queryOption',
    method: 'post',
    data: data
  })
}

// 删除问题题目
export function examQuDel(data) {
  return request({
    url: '/exam/qu/del',
    method: 'post',
    data: data
  })
}
// 查询问题题目详细
export function examQu(id) {
  return request({
    url: '/exam/qu/' + id,
    method: 'get'
  })
}

// 新增问题题目
export function examQuAdd(data) {
  return request({
    url: '/exam/qu/add',
    method: 'post',
    data: data
  })
}

// 修改问题题目
export function examQuEdit(data) {
  return request({
    url: '/exam/qu/edit',
    method: 'post',
    data: data
  })
}
// 获取培训课程列表
export function examSecuritycourseList(data) {
  return request({
    url: '/exam/securitycourse/list',
    method: 'post',
    data: data
  })
}
//删除课程
export function examSecuritycourseDel(data) {
  return request({
    url: '/exam/securitycourse/del',
    method: 'post',
    data: data
  })
}
// 获取培训课程详情
export function securitycourseInfo(id) {
  return request({
    url: '/exam/securitycourse/'+id,
    method: 'get',
  })
}

//获取详情学生列表
export function singList(data) {
  return request({
    url: '/exam/securitycourse/singList',
    method: 'post',
    data: data
  })
}


// 查询学生列表
export function findUserList(data) {
  return request({
    url: '/system/user/list',
    method: 'post',
    data: data
  })
}
// 查询老师列表
export function selectUser(data) {
  return request({
    url: '/system/user/selectUser',
    method: 'post',
    data: data
  })
}
// 查询学院列表
export function departmentsList(query) {
  return request({
    url: '/system/dept/departments/list',
    method: 'get',
    params: query
  })
}
// 查询实验室列表
// export function subListAdmin(query) {
//   return request({
//     url: '/laboratory/subject/list/listAdmin',
//     method: 'get',
//     params: query
//   })
// }



//新增课程
export function examSecuritycourseAdd(data) {
  return request({
    url: '/exam/securitycourse/add',
    method: 'post',
    data: data
  })
}
//编辑课程
export function securitycourseEdit(data) {
  return request({
    url: '/exam/securitycourse/edit',
    method: 'post',
    data: data
  })
}

